import { PDFPageProxy, PDFPageViewport, PDFPromise } from 'pdfjs-dist';
import { PDFDataRangeTransport } from './pdfapi';
import { PdfjsItem } from './pdfjs-item';
import { InjectionToken } from '@angular/core';
import { Observable } from 'rxjs';
export declare const PDF_API: InjectionToken<Observable<string>>;
export declare class PdfjsItemEvent {
    item: PdfjsItem;
    event: PdfjsItemEventType;
    from?: number;
    to?: number;
}
export declare enum PdfjsItemEventType {
    INIT = "init",
    UPDATE = "update",
    ADD = "add",
    REMOVE = "remove",
    END_INIT = "endInit"
}
export declare class PdfjsItemAddEvent extends PdfjsItemEvent {
    event: PdfjsItemEventType.ADD;
    constructor(data: {
        item: PdfjsItem;
        to: number;
    });
}
export declare class PdfjsItemRemoveEvent extends PdfjsItemEvent {
    event: PdfjsItemEventType.REMOVE;
    constructor(data: {
        item: PdfjsItem;
    });
}
export interface CanvasWrapperRenderEvent {
    viewport: PDFPageViewport;
    pdfPageProxy: PDFPageProxy;
    width: number;
    height: number;
}
export interface PreviewEvent {
    item: PdfjsItem;
    atTop: boolean;
    atLeft: boolean;
    x: number;
    y: number;
    width: number;
    height: number;
}
export declare class RenderEvent {
    type: RenderEventType;
    page: number;
    pages: number;
    time: number;
}
export declare enum RenderEventType {
    START = "START",
    PROGRESS = "PROGRESS",
    END = "END"
}
export interface PdfPage {
    pdfId: string;
    document: PdfSource;
    pageIdx: number;
    rotation: number;
}
export declare enum ThumbnailLayout {
    HORIZONTAL = "horizontal",
    VERTICAL = "vertical"
}
export declare enum ViewFit {
    HORIZONTAL = "horizontal",
    VERTICAL = "vertical"
}
export declare enum ThumbnailDragMode {
    NONE = "none",
    MOVE = "move",
    DUPLICATE = "duplicate"
}
export declare type ThumbnailOver = ThumbnailOverValues.RIGHT | ThumbnailOverValues.LEFT | ThumbnailOverValues.BOTTOM | ThumbnailOverValues.TOP;
export declare enum ThumbnailOverValues {
    RIGHT = "right",
    LEFT = "left",
    BOTTOM = "bottom",
    TOP = "top"
}
export declare type RenderQuality = 1 | 2 | 3 | 4 | 5;
export declare type PdfSource = string | PDFDataRangeTransport | Uint8Array | {
    data: Uint8Array;
} | {
    range: PDFDataRangeTransport;
} | {
    url: string;
    cMapUrl?: string;
    cMapPacked?: boolean;
};
export declare class PdfjsConfig {
    workerSrc: string;
    cMapUrl?: string;
    cMapPacked?: boolean;
}
export declare class PDFPromiseResolved<T> implements PDFPromise<T> {
    private res;
    constructor(res: T);
    isResolved: () => true;
    isRejected: () => false;
    resolve: (value: T) => void;
    reject: (reason: string) => void;
    then<U>(onResolve: (promise: T) => U, onReject?: (reason: string) => void): PDFPromiseResolved<U>;
}
