import { ApplicationRef, ComponentFactoryResolver, ComponentRef, ElementRef, EventEmitter, Injector, OnDestroy, OnInit, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { PdfjsControl } from '../../controls/pdfjs-control';
import { PdfjsGroupControl } from '../../controls/pdfjs-group-control';
import { PdfjsItemEvent, PreviewEvent, RenderEvent, RenderQuality, ThumbnailDragMode, ThumbnailLayout } from '../../classes/pdfjs-objects';
import { ThumbnailDragService } from '../../services/thumbnail-drag.service';
import { PdfjsThumbnailComponent } from '../pdfjs-thumbnail/pdfjs-thumbnail.component';
export declare class PdfjsThumbnailsComponent implements OnInit, OnDestroy {
    private cfr;
    private defaultInjector;
    private appRef;
    private elementRef;
    private thumbnailDragService;
    ThumbnailDragMode: typeof ThumbnailDragMode;
    render: EventEmitter<RenderEvent>;
    container: ViewContainerRef;
    previewRef: ElementRef;
    vertical: boolean;
    itemEvent$: Subject<PdfjsItemEvent>;
    thumbnailComponentRefs: Array<ComponentRef<PdfjsThumbnailComponent>>;
    previewEvent: PreviewEvent;
    /**
     * Height of preview
     */
    previewHeight: number;
    /**
     * quality of preview
     */
    previewQuality: RenderQuality;
    private init;
    private items;
    private itemToRenderCount;
    private subOnPdfjsGroupCtrl;
    private subOnPdfjsCtrl;
    private containerIsSelected;
    private innerQuality;
    private innerFitSize;
    private innerPreviewDelay;
    private innerDragMode;
    private innerBorderWidth;
    private innerAllowRemove;
    private innerAllowDrop;
    private innerPdfjsControl;
    private innerPdfjsGroupControl;
    constructor(cfr: ComponentFactoryResolver, defaultInjector: Injector, appRef: ApplicationRef, elementRef: ElementRef, thumbnailDragService: ThumbnailDragService);
    /**
    * The quality of pdf render
    */
    quality: RenderQuality;
    /**
    * size to fitSelected. Depends of direction layout
    */
    fitSize: number;
    /**
    * Delay for show preview. 0 => disable preview
    */
    previewDelay: number;
    /**
    * Drag mode
    */
    dragMode: ThumbnailDragMode;
    borderWidth: number;
    /**
    * The remove button on thumbnail is it visible
    */
    allowRemove: boolean;
    /**
    * This container accept drop thumbnail
    */
    allowDrop: boolean;
    /**
    * Define the pdfjsControl for this thumbnail container
    */
    pdfjsControl: PdfjsControl;
    /**
    * Define the pdfjsGroupControl for thumbnail containers
    */
    pdfjsGroupControl: PdfjsGroupControl;
    /**
    * Layout direction
    */
    layout: ThumbnailLayout;
    /**
     * Start process of drag thumbnail
     */
    onDragStart(event: DragEvent): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * scrolling
     */
    onScroll(): void;
    mouseOut(): void;
    isNativeElementEqual(element: HTMLElement): boolean;
    private ctrlItemEventInitHandler;
    private ctrlItemEventEndInitHandler;
    private ctrlItemEventOtherHandler;
    /**
     * compute sizes of thumbnail
     */
    private computeSizes;
    private unsubOnPdfjsGroupCtrl;
    private unsubOnPdfjsCtrl;
    private unregisterDragService;
    private removeThumbnail;
    private selection;
    private nextThumbnail;
    /**
     * remove PdfjsThumbnailComponent from dom
     */
    private removeThumbnailComponentToDom;
    /**
     * add ThumbnailComponent to dom
     */
    private addThumbnailComponentToDom;
    private updateThumbnailComponentToDom;
    private initThumbnailComponent;
    private progressLoading;
    private startLoading;
}
